package config

import (
	"github.com/caarlos0/env/v8"
	"github.com/joho/godotenv"
)

type Config struct {
	TelegramToken      string `env:"TELEGRAM_TOKEN,required"`
	TelegramChannelID  int64  `env:"TELEGRAM_CHANNEL_ID,required"`
	HttpAddressUser    string `env:"HTTP_ADDRESS_USER,required"`
	HttpAddressAdmin   string `env:"HTTP_ADDRESS_ADMIN,required"`
	MongoHost          string `env:"MONGO_HOST,required"`
	MongoPort          string `env:"MONGO_PORT,required"`
	MongoUser          string `env:"MONGO_USER,required"`
	MongoPassword      string `env:"MONGO_PASSWORD,required"`
	MongoAuth          string `env:"MONGO_AUTH,required"`
	DatabaseName       string `env:"MONGO_DATABASE_NAME,required"`
	S3Endpoint         string `env:"S3_ENDPOINT,required"`
	S3AccessKeyID      string `env:"S3_ACCESS_KEY_ID,required"`
	S3SecretKey        string `env:"S3_SECRET_KEY,required"`
	CustomerSvcAddress string `env:"CUSTOMER_SVC_ADDRESS,required"`
	StagingURL         string `env:"STAGING_URL,required"`
	S3Folder           string `env:"S3_FOLDER,required"`
	S3FileUrl          string `env:"S3_FILE_URL,required"`
	CustomerRPCHost    string `env:"CUSTOMER_RPC_HOST,required"`
	TrashLogHost       string `env:"TRASH_LOG_HOST,required"`
	ModuleLogger       string `env:"MODULE_LOGGER,required"`
}

func NewConfig(file ...string) (*Config, error) {
	if err := godotenv.Load(file...); err != nil {
		return nil, err
	}

	var cfg Config
	if err := env.Parse(&cfg); err != nil {
		return nil, err
	}

	return &cfg, nil
}
